@@ -22,7 +22,7 @@ class CoinServer(BaseServer):
 
         manage.add_job(server_name='notecoin_server',
                        directory=self.current_path,
-                       command=f"uvicorn notecoin_server:app --host '0.0.0.0' --port 8444 --reload",
+                       command=f"uvicorn notecoin_server:app --host '0.0.0.0' --port 8444",
                        user='bingtao',
                        stdout_logfile="/notechats/logs/notecoin/strategy.log")
         manage.start()
